==> myfaces-tobago-1.5.13-source-release.zip: tobago-1.5.13/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/IsGridLayoutComponentWithDimension.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.taglib.declaration;

import org.apache.myfaces.tobago.apt.annotation.TagAttribute;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;

/**
 * The width and height attributes can be set explicitly on some components.
 * Generally it should be checked, if using of a layout manager is a better alternative.
 */
public interface IsGridLayoutComponentWithDimension extends IsGridLayoutComponentBase {

  /**
   * The width of the component in the UI.
   * This value will usually be set by the layout manager, but can be set explicitly here.
   *
   * @param width The width for this component.
   */
  @TagAttribute
  @UIComponentTagAttribute(type = "org.apache.myfaces.tobago.layout.Measure",
      defaultCode = "((LayoutComponentRenderer)getRenderer(getFacesContext())).getWidth(getFacesContext(), this)")
  void setWidth(String width);

  /**
   * The height of the component in the UI.
   * This value will usually be set by the layout manager, but can be set explicitly here.
   *
   * @param height The height for this component.
   */
  @TagAttribute
  @UIComponentTagAttribute(type = "org.apache.myfaces.tobago.layout.Measure",
      defaultCode = "((LayoutComponentRenderer)getRenderer(getFacesContext())).getHeight(getFacesContext(), this)")
  void setHeight(String height);

}

==> myfaces-tobago-2.4.0-source-release.zip: tobago-2.4.0/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/declaration/IsGridLayoutComponentWithDimension.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.taglib.declaration;

import org.apache.myfaces.tobago.apt.annotation.TagAttribute;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;

/**
 * The width and height attributes can be set explicitly on some components.
 * Generally it should be checked, if using of a layout manager is a better alternative.
 */
public interface IsGridLayoutComponentWithDimension extends IsGridLayoutComponentBase {

  /**
   * The width of the component in the UI.
   * This value will usually be set by the layout manager, but can be set explicitly here.
   *
   * @param width The width for this component.
   */
  @TagAttribute
  @UIComponentTagAttribute(type = "org.apache.myfaces.tobago.layout.Measure",
      defaultCode = "getRendererType() != null ? ((LayoutComponentRenderer)"
          + " getRenderer(getFacesContext())).getWidth(getFacesContext(), this) : Measure.ZERO")
  void setWidth(String width);

  /**
   * The height of the component in the UI.
   * This value will usually be set by the layout manager, but can be set explicitly here.
   *
   * @param height The height for this component.
   */
  @TagAttribute
  @UIComponentTagAttribute(type = "org.apache.myfaces.tobago.layout.Measure",
      defaultCode = "getRendererType() != null ? ((LayoutComponentRenderer)"
          + " getRenderer(getFacesContext())).getHeight(getFacesContext(), this) : Measure.ZERO")
  void setHeight(String height);

}
